@@ -11,8 +11,8 @@
 #include "icalimporter.h"
 #include "incidencechanger.h"
 
-#include <collection.h>
-#include <item.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 #include <QList>
 #include <QObject>
@@ -28,12 +28,12 @@ class Job;
 
 namespace Akonadi
 {
-class Q_DECL_HIDDEN ICalImporter::Private : public QObject
+class ICalImporterPrivate : public QObject
 {
     Q_OBJECT
 public:
-    Private(Akonadi::IncidenceChanger *changer, ICalImporter *qq);
-    ~Private();
+    ICalImporterPrivate(Akonadi::IncidenceChanger *changer, ICalImporter *qq);
+    ~ICalImporterPrivate() override;
     void setErrorMessage(const QString &message);
 
     ICalImporter *const q;
